==> ternyxmimosa-0.0.8.tar.gz: ternyxmimosa-0.0.8/README.md <==
<!-- Inspired by https://github.com/othneildrew/Best-README-Template/blob/master/BLANK_README.md -->

<a name="readme-top"></a>


<!-- SHIELDS HEADER -->
<div align="center">


[![contributors-shield]][contributors-url] [![Forks][forks-shield]][forks-url] [![Stargazers][stars-shield]][stars-url] [![Issues][issues-shield]][issues-url] [![MIT License][license-shield]][license-url] [![LinkedIn][linkedin-shield]][linkedin-url]

[contributors-shield]: https://img.shields.io/github/contributors/EJOOSTEROP/mimosa.svg?logo=github
[contributors-url]: https://github.com/EJOOSTEROP/mimosa/graphs/contributors

[forks-shield]: https://img.shields.io/github/forks/EJOOSTEROP/mimosa.svg?logo=github
[forks-url]: https://github.com/EJOOSTEROP/mimosa/network/members

[stars-shield]: https://img.shields.io/github/stars/EJOOSTEROP/mimosa.svg?logo=github
[stars-url]: https://github.com/EJOOSTEROP/mimosa/stargazers

[issues-shield]: https://img.shields.io/github/issues/EJOOSTEROP/mimosa.svg?logo=github
[issues-url]: https://github.com/EJOOSTEROP/mimosa/issues

[license-shield]: https://img.shields.io/github/license/EJOOSTEROP/mimosa.svg?logo=github
[license-url]: https://github.com/EJOOSTEROP/mimosa/blob/main/LICENSE.txt

[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/erik-oosterop-9505a21

<!-- no PyPi repository
[![PyPI - Python Version][pypi-python-shield]][https://pypi.org/project/x_mimosa_x]

[pypi-python-shield]: https://img.shields.io/pypi/pyversions/mimosa?logo=python


[![PyPi - Package Version][pypi-version-shield]][https://pypi.org/project/x_mimosa_x]

[pypi-version-shield]: https://img.shields.io/pypi/v/mimosa?logo=python


[![PyPi - License][pypi-license-shield]][license-url]

[pypi-license-shield]: https://img.shields.io/pypi/l/mimosa?logo=python
-->
</div>

<!-- PROJECT SUMMARY AND LOGO -->
<div align="center">
  <a href="https://github.com/EJOOSTEROP/mimosa">
    <img src="https://github.com/EJOOSTEROP/mimosa/blob/main/etc/logo.png?raw=true" alt="Logo" width="180" height="180">
  </a>

<h3 align="center">mimosa</h3>

  <p align="center">
    A minimal modern data stack with working data pipelines in a single Docker container.
    <br />
    <a href="https://github.com/EJOOSTEROP/mimosa"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <!--
    <a href="https://github.com/EJOOSTEROP/mimosa">View Demo</a>
    ·
    -->
    <a href="https://github.com/EJOOSTEROP/mimosa/issues">Report Bug</a>
    ·
    <a href="https://github.com/EJOOSTEROP/mimosa/issues">Request Feature</a>
  </p>
</div>


<!-- TABLE OF CONTENTS -->
<br />
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About the Project</a>
      <!-- <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul> -->
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <!-- <li><a href="#license">License</a></li> -->
    <li><a href="#contact">Contact</a></li>
    <!-- <li><a href="#acknowledgments">Acknowledgments</a></li> -->
  </ol>
</details>

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- ABOUT THE PROJECT -->
## About the Project

<div  align="center">
  <a href="https://github.com/EJOOSTEROP/mimosa">
    <img src="https://github.com/EJOOSTEROP/mimosa/blob/main/etc/intro_image.jpg?raw=true" alt="intro_image" width="75%" height="75%">
  </a>
</div>

<div>

<br /><br />

**THIS IS A CONCEPT AND WORK IN PROGRESS**

A minimal modern data stack with working data pipelines in a single Docker container. This is similar in concept to [mimodast][mimodast-repo-url] using alternative software options.
<!-- MIMOdast Software Alternatives -->

Useful for an exploration of the tools involved:
- [dltHub][dlthub-url] for data loading

</div>

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- BUILT WITH -->
<!--
### Built With

<p align="right">(<a href="#readme-top">back to top</a>)</p>
-->


<!-- GETTING STARTED -->
## Getting Started

<!--To get a local copy up and running follow these simple example steps.
-->

### Prerequisites

<p align="right">(<a href="#readme-top">back to top</a>)</p>

### Installation

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- USAGE EXAMPLES -->
## Usage

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- ROADMAP -->
## Roadmap

<div>
Consider:

- [x] Get source data (Using REST API)
- [ ] Transform data, possibly SQL Mesh or dbt.
  - [ ] Create data vault transformations (https://automate-dv.readthedocs.io/en/latest/).
- [ ] dlt update/error messages using Slack
- [-] Storage (currently local DuckDB, maybe consider some cloud alternative. Though that would stray from the data stack in a Docker concept.)
- [ ] Scheduling Tool
- [ ] Reporting tool (Metabase?)
</div>

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- CONTRIBUTING -->
## Contributing

<!-- Contributions are what make the open source community such an amazing place to learn, inspire, and create. -->
Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also [open](https://github.com/EJOOSTEROP/mimosa/issues/new/choose) a feature request or bug report.
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- LICENSE -->
<!--
## License

Distributed under the MIT License. See `LICENSE.txt` for more information. The tools and the sample data are subject to their own respective licenses.

<p align="right">(<a href="#readme-top">back to top</a>)</p>
-->


<!-- CONTACT -->
## Contact

<!--
Your Name - [@twitter_handle](https://twitter.com/twitter_handle) - email@email_client.com
-->

Project Link: [mimosa](https://github.com/EJOOSTEROP/mimosa)

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- ACKNOWLEDGMENTS -->
<!--
## Acknowledgments

* []()
* []()
* []()

<p align="right">(<a href="#readme-top">back to top</a>)</p>

-->

<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->

[mimodast-repo-url]: https://github.com/EJOOSTEROP/mimodast
[dlthub-url]: https://dlthub.com/

==> ternyxmimosa-0.0.11.tar.gz: ternyxmimosa-0.0.11/README.md <==
<!-- Inspired by https://github.com/othneildrew/Best-README-Template/blob/master/BLANK_README.md -->

<a name="readme-top"></a>


<!-- SHIELDS HEADER -->
<div align="center">


[![contributors-shield]][contributors-url] [![Forks][forks-shield]][forks-url] [![Stargazers][stars-shield]][stars-url] [![Issues][issues-shield]][issues-url] [![MIT License][license-shield]][license-url] [![LinkedIn][linkedin-shield]][linkedin-url]

[contributors-shield]: https://img.shields.io/github/contributors/EJOOSTEROP/mimosa.svg?logo=github
[contributors-url]: https://github.com/EJOOSTEROP/mimosa/graphs/contributors

[forks-shield]: https://img.shields.io/github/forks/EJOOSTEROP/mimosa.svg?logo=github
[forks-url]: https://github.com/EJOOSTEROP/mimosa/network/members

[stars-shield]: https://img.shields.io/github/stars/EJOOSTEROP/mimosa.svg?logo=github
[stars-url]: https://github.com/EJOOSTEROP/mimosa/stargazers

[issues-shield]: https://img.shields.io/github/issues/EJOOSTEROP/mimosa.svg?logo=github
[issues-url]: https://github.com/EJOOSTEROP/mimosa/issues

[license-shield]: https://img.shields.io/github/license/EJOOSTEROP/mimosa.svg?logo=github
[license-url]: https://github.com/EJOOSTEROP/mimosa/blob/main/LICENSE.txt

[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/erik-oosterop-9505a21

<!-- no PyPi repository
[![PyPI - Python Version][pypi-python-shield]][https://pypi.org/project/x_mimosa_x]

[pypi-python-shield]: https://img.shields.io/pypi/pyversions/mimosa?logo=python


[![PyPi - Package Version][pypi-version-shield]][https://pypi.org/project/x_mimosa_x]

[pypi-version-shield]: https://img.shields.io/pypi/v/mimosa?logo=python


[![PyPi - License][pypi-license-shield]][license-url]

[pypi-license-shield]: https://img.shields.io/pypi/l/mimosa?logo=python
-->
</div>

<!-- PROJECT SUMMARY AND LOGO -->
<div align="center">
  <a href="https://github.com/EJOOSTEROP/mimosa">
    <img src="https://github.com/EJOOSTEROP/mimosa/blob/main/etc/logo.png?raw=true" alt="Logo" width="180" height="180">
  </a>

<h3 align="center">mimosa</h3>

  <p align="center">
    A minimal modern data stack with working data pipelines in a single Docker container.
    <br />
    <a href="https://github.com/EJOOSTEROP/mimosa"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <!--
    <a href="https://github.com/EJOOSTEROP/mimosa">View Demo</a>
    ·
    -->
    <a href="https://github.com/EJOOSTEROP/mimosa/issues">Report Bug</a>
    ·
    <a href="https://github.com/EJOOSTEROP/mimosa/issues">Request Feature</a>
  </p>
</div>


<!-- TABLE OF CONTENTS -->
<br />
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About the Project</a>
      <!-- <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul> -->
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <!-- <li><a href="#license">License</a></li> -->
    <li><a href="#contact">Contact</a></li>
    <!-- <li><a href="#acknowledgments">Acknowledgments</a></li> -->
  </ol>
</details>

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- ABOUT THE PROJECT -->
## About the Project

<div  align="center">
  <a href="https://github.com/EJOOSTEROP/mimosa">
    <img src="https://github.com/EJOOSTEROP/mimosa/blob/main/etc/intro_image.jpg?raw=true" alt="intro_image" width="75%" height="75%">
  </a>
</div>

<div>

<br /><br />

**THIS IS A CONCEPT AND WORK IN PROGRESS**

A minimal modern data stack with working data pipelines in a single Docker container. This is similar in concept to [mimodast][mimodast-repo-url] using alternative software options.
<!-- MIMOdast Software Alternatives -->

Useful for an exploration of the tools involved:
- [dltHub][dlthub-url] for data loading

</div>

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- BUILT WITH -->
<!--
### Built With

<p align="right">(<a href="#readme-top">back to top</a>)</p>
-->


<!-- GETTING STARTED -->
## Getting Started

<!--To get a local copy up and running follow these simple example steps.
-->

### Prerequisites

<p align="right">(<a href="#readme-top">back to top</a>)</p>

### Installation

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- USAGE EXAMPLES -->
## Usage

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- ROADMAP -->
## Roadmap

<div>
Consider:

- [x] Get source data (Using REST API)
- [x] Transform data, possibly SQL Mesh or dbt.
  - [ ] Create data vault transformations (https://automate-dv.readthedocs.io/en/latest/).
- [ ] dlt update/error messages using Slack
- [-] Storage (currently local DuckDB, maybe consider some cloud alternative. Though that would stray from the data stack in a Docker concept.)
- [ ] Scheduling Tool
- [ ] Reporting tool (Metabase?)
</div>

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- CONTRIBUTING -->
## Contributing

<!-- Contributions are what make the open source community such an amazing place to learn, inspire, and create. -->
Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also [open](https://github.com/EJOOSTEROP/mimosa/issues/new/choose) a feature request or bug report.
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- LICENSE -->
<!--
## License

Distributed under the MIT License. See `LICENSE.txt` for more information. The tools and the sample data are subject to their own respective licenses.

<p align="right">(<a href="#readme-top">back to top</a>)</p>
-->


<!-- CONTACT -->
## Contact

<!--
Your Name - [@twitter_handle](https://twitter.com/twitter_handle) - email@email_client.com
-->

Project Link: [mimosa](https://github.com/EJOOSTEROP/mimosa)

<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- ACKNOWLEDGMENTS -->
<!--
## Acknowledgments

* []()
* []()
* []()

<p align="right">(<a href="#readme-top">back to top</a>)</p>

-->

<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->

[mimodast-repo-url]: https://github.com/EJOOSTEROP/mimodast
[dlthub-url]: https://dlthub.com/
